@@ -15,7 +15,7 @@ catch {package require Tk}
 # This is for easy testing purposes when wsurf has not been installed
 
 set auto_path [concat [file join [file dirname [info script]] ..] $auto_path]
-package require -exact wsurf 1.7
+package require -exact wsurf 1.8
 
 
 # Initialize wsurf package (this will set default preferences)
@@ -24,7 +24,7 @@ package require -exact wsurf 1.7
 
 # Make widget scroll during playback
 
-set scroll Page
+set scroll Scroll
 wsurf::SetPreference autoScroll $scroll
 
 
@@ -39,7 +39,7 @@ pack $widget -expand 0 -fill both
 
 # Add a couple of panes and some content from the standard plug-ins
 # These lines have been copied from the standard Waveform configuration,
-# ../wsurf1.7/configurations/Waveform.conf
+# ../wsurf1.8/configurations/Waveform.conf
 
 set pane [$widget addPane -maxheight 2048  -minheight 10]
 $widget analysis::addWaveform $pane
@@ -90,6 +90,8 @@ snack::createIcons
 
 pack [button .a -image snackOpen -command Load] -side left
 
-pack [checkbutton .b -text "Play scroll" -variable scroll \
-      -onvalue Page -offvalue None \
-      -command {wsurf::SetPreference autoScroll $scroll}] -side left
+
+foreach type [list None Page Scroll] {
+ pack [radiobutton .r$type -text $type -value $type -variable scroll \
+	   -command [list wsurf::SetPreference autoScroll $type]] -side left
+}
