@@ -12,17 +12,20 @@ catch {package require Tk}
 
 set auto_path [concat [file join [file dirname [info script]] ..] $auto_path]
 
-package require -exact wsurf 1.7
+package require -exact wsurf 1.8
 
 ::wsurf::Initialize
 
 
+wsurf::SetPreference yaxisWidth 0
+
 # Create and pack two wsurf widgets using Waveform configurations
 
 set ind [lsearch [::wsurf::GetConfigurations] *Waveform*]
 set conf [lindex [::wsurf::GetConfigurations] $ind]
 
 set w1 [wsurf .w1 -collapser 0 -configuration $conf -icons [list play pause stop zoomin zoomout]]
+grid forget $w1.workspace.wavebar.c0
 pack $w1 -expand 0 -fill both
 
 set w2 [wsurf .w2 -collapser 0 -configuration $conf -icons [list play pause stop zoomin zoomout]]
