@@ -14,7 +14,7 @@ catch {package require Tk}
 # This is for easy testing purposes when wsurf has not been installed
 
 set auto_path [concat [file join [file dirname [info script]] ..] $auto_path]
-package require -exact wsurf 1.7
+package require -exact wsurf 1.8
 
 # Initialize wsurf package (this will set default preferences)
 
@@ -37,9 +37,9 @@ pack $widget -expand 0 -fill both
 
 # Add a couple of panes and some content from the standard plug-ins
 # These lines have been copied from the standard Waveform configuration,
-# ../wsurf1.7/configurations/Waveform.conf
+# ../wsurf1.8/configurations/Waveform.conf
 
-set pane [$widget addPane -maxheight 2048  -minheight 10]
+set pane [$widget addPane -maxheight 2048  -minheight 10 -state disabled]
 $widget analysis::addWaveform $pane
 
 set pane [$widget addPane -maxheight 20  -minheight 20]
